@@ -240,14 +240,26 @@ class RuleEngine:
     def last_events(self) -> List[str]:
         return self.__last_events
 
+    @property
+    def last_event(self) -> str:
+        return self.__last_events[-1]
+
     @property
     def last_handled_events(self) -> List[str]:
         return self.__last_handled_events
 
+    @property
+    def last_handled_event(self) -> str:
+        return self.__last_handled_events[-1]
+
     @property
     def last_crons(self) -> List[str]:
         return self.__cron_scheduler.last_crons
 
+    @property
+    def last_cron(self) -> str:
+        return self.__cron_scheduler.last_crons[-1]
+
     def start(self):
         if self.python_rule_directory not in sys.path:
             sys.path.insert(0, self.python_rule_directory)
@@ -260,7 +272,7 @@ class RuleEngine:
     def add_trigger(self, trigger: Trigger):
         rules = self.rules
         if trigger.is_valid():
-            logging.info(" * " + trigger.name + "(...): register trigger '" + trigger.expression + "'")
+            logging.info(" * " + trigger.name + "(...): trigger '" + trigger.expression + "' has been registered")
             self.__trigger_registry.register(trigger)
             if isinstance(trigger, CronTrigger):
                 self.__cron_scheduler.add_job(trigger)
@@ -281,12 +293,12 @@ class RuleEngine:
                 modulename = self.__filename_to_modulename(filename)
                 # reload?
                 if modulename in sys.modules:
-                    logging.info("reload '" + filename + "'")
+                    logging.info("reloading '" + filename + "'")
                     self.__cron_scheduler.remove_jobs(modulename)
                     self.__trigger_registry.deregister(modulename)
                     importlib.reload(sys.modules[modulename])
                 else:
-                    logging.info("load '" + filename + "'")
+                    logging.info("loading '" + filename + "'")
                     importlib.import_module(modulename)
             except Exception as e:
                 logging.warning("error occurred by (re)loading " + filename, e)
@@ -295,7 +307,7 @@ class RuleEngine:
         try:
             modulename = self.__filename_to_modulename(filename)
             if modulename in sys.modules:
-                logging.info("unload '" + filename + "'")
+                logging.info("unloading '" + filename + "'")
                 self.__cron_scheduler.remove_jobs(modulename)
                 self.__trigger_registry.deregister(modulename)
                 del sys.modules[modulename]
@@ -350,5 +362,5 @@ class RuleEngine:
                 rules.add(rule)
         return sorted(list(rules))
 
-#RuleEngine.start_singleton("http://192.168.1.27:8080", "C:\\workspace\\test", "test", "test")
+#RuleEngine.start_singleton("http://192.168.1.27:8080", "C:\\workspace\\test", sys.argv[1], sys.argv[2])
 #sleep(10000)
\ No newline at end of file
